summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorhellzbellz <31550512+Hellzbellz123@users.noreply.github.com>2022-07-12 10:36:43 -0700
committerGitHub <noreply@github.com>2022-07-12 19:36:43 +0200
commit0c7ce363c903e1e3255d4d30255ff4790678ace9 (patch)
tree95926642e0e390eb552b51a4398cfc3929a359f0 /lib
parent0726c1099fec6599dbf91a260f21d6d45fd8f309 (diff)
downloadzsh-0c7ce363c903e1e3255d4d30255ff4790678ace9.tar.gz
zsh-0c7ce363c903e1e3255d4d30255ff4790678ace9.tar.bz2
zsh-0c7ce363c903e1e3255d4d30255ff4790678ace9.zip
chore(lib): only create `afind` alias if `ack` is installed (#11017)
Diffstat (limited to 'lib')
-rw-r--r--lib/misc.zsh4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/misc.zsh b/lib/misc.zsh
index a5d3af998..1f637083a 100644
--- a/lib/misc.zsh
+++ b/lib/misc.zsh
@@ -24,10 +24,10 @@ env_default 'LESS' '-R'
## super user alias
alias _='sudo '
## more intelligent acking for ubuntu users
if (( $+commands[ack-grep] )); then
alias afind='ack-grep -il'
-else
+elif (( $+commands[ack] )); then
alias afind='ack -il'
fi
@@ -24,10 +24,10 @@ env_default 'LESS' '-R'
## super user alias
alias _='sudo '
-## more intelligent acking for ubuntu users
+## more intelligent acking for ubuntu users and no alias for users without ack
if (( $+commands[ack-grep] )); then
alias afind='ack-grep -il'